pub struct ScheduleVariable {
pub variable: CompactString,
}Fields
variable: CompactStringTrait Implementations
Sourceimpl Clone for ScheduleVariable
impl Clone for ScheduleVariable
Sourcefn clone(&self) -> ScheduleVariable
fn clone(&self) -> ScheduleVariable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ScheduleVariable
impl ComposeSchema for ScheduleVariable
Sourceimpl<'de> Deserialize<'de> for ScheduleVariable
impl<'de> Deserialize<'de> for ScheduleVariable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ScheduleVariable
impl Serialize for ScheduleVariable
Sourceimpl ToSchema for ScheduleVariable
impl ToSchema for ScheduleVariable
Sourceimpl Validate for ScheduleVariable
impl Validate for ScheduleVariable
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for ScheduleVariable
impl RefUnwindSafe for ScheduleVariable
impl Send for ScheduleVariable
impl Sync for ScheduleVariable
impl Unpin for ScheduleVariable
impl UnwindSafe for ScheduleVariable